Base Classes
============

Base classes used across multiple modules.

OBO Entity
----------

.. automodule:: tacular.obo_entity
   :members:
   :undoc-members:
   :show-inheritance:

OBO Lookup
----------

.. automodule:: tacular.obo_lookup
   :members:
   :undoc-members:
   :show-inheritance:
